@@ -12,7 +12,6 @@ class UserInfo:
         # for testing wrong formatted username, put the name before generated id
         self.used_name = f"{self.name}xxxxxx{new_rand_test_user_name()}"
         self.password = password
-        self.user_id = None
         self.token = None
         self.login_info = None
 
@@ -20,9 +19,11 @@ class UserInfo:
         login = act__signup(self.used_name, self.password)
         assert login[AA.Name] == self.used_name
         self.password = login[AA.Password]
-        self.user_id = login[AA.UserId]
 
-    def login(self):
+    def login(self, forced=False):
+        if not forced and self.login_info is not None:
+            return
+
         # print("act__login")
         self.login_info = act__login(self.used_name, self.password)
         # print("set token")
@@ -36,13 +37,18 @@ class UserPool:
     def __init__(self):
         self.users = dict()
 
-    def get_user(self, name: str):
+    def get_user(self, name: str) -> UserInfo:
         name = BehaveUtil.clear_string(name)
         if name not in self.users:
             return None
 
         return self.users[name]
 
+    def get_login_user(self, name: str) -> UserInfo:
+        user = self.get_user(name)
+        user.login()
+        return user
+
     def add_user(self, name: str, password: str = None) -> UserInfo:
         name = BehaveUtil.clear_string(name)
         assert name not in self.users
